==> haskell-config-ini-0.2.4.0-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-ini
version:              0.2.4.0
visibility:           public
id:                   config-ini-0.2.4.0-GuzhlmLiAxh3OCyENiB7Ia
key:                  config-ini-0.2.4.0-GuzhlmLiAxh3OCyENiB7Ia
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <config-ini@infinitenegativeutility.com>
author:               Getty Ritter <config-ini@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/config-ini
synopsis:             A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.

    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)

category:             Configuration
abi:                  17d4e32e8a6a088e9f58a11d48f9c8c7
exposed:              True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw

import-dirs:          /usr/lib/ghc-8.10.1/site-local/config-ini-0.2.4.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/config-ini-0.2.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/config-ini-0.2.4.0
hs-libraries:         HSconfig-ini-0.2.4.0-GuzhlmLiAxh3OCyENiB7Ia
depends:
    base-4.14.0.0 containers-0.6.2.1
    megaparsec-8.0.0-KpdQ9LEGN4p9QotiwOIGMX text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-G13aGNInC3gBl4w7zg86q

haddock-interfaces:   /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html:         /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-ini-0.2.4.0-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-ini
version:              0.2.4.0
visibility:           public
id:                   config-ini-0.2.4.0-2kw7S8xHWa0HxUGcuFksAP
key:                  config-ini-0.2.4.0-2kw7S8xHWa0HxUGcuFksAP
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <config-ini@infinitenegativeutility.com>
author:               Getty Ritter <config-ini@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/config-ini
synopsis:             A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.

    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)

category:             Configuration
abi:                  47bc6fbeba649ca4f1ebdf21ad56e282
exposed:              True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw

import-dirs:          /usr/lib/ghc-8.10.1/site-local/config-ini-0.2.4.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/config-ini-0.2.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/config-ini-0.2.4.0
hs-libraries:         HSconfig-ini-0.2.4.0-2kw7S8xHWa0HxUGcuFksAP
depends:
    base-4.14.0.0 containers-0.6.2.1
    megaparsec-8.0.0-KH48QCQgKyXHGvfMj5dJeN text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-ICA6ej5I5Fj46rua6lwZRd

haddock-interfaces:   /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html:         /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
